==> haskell-checkers-0.4.10-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.10
id: checkers-0.4.10-2Kt4oAEpHgS7cUYpTvLtIt
key: checkers-0.4.10-2Kt4oAEpHgS7cUYpTvLtIt
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: 5c058be70798092354ce9a33d0d56a17
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.4.3/site-local/checkers-0.4.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/checkers-0.4.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/checkers-0.4.10
hs-libraries: HScheckers-0.4.10-2Kt4oAEpHgS7cUYpTvLtIt
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr array-0.5.2.0
    base-4.11.1.0 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    semigroupoids-5.3.1-CUPD9rRErPJCB8rgcbyu7X
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             semigroupoids-5.3.1-CUPD9rRErPJCB8rgcbyu7X=cdec372b94ffd1d13cacf4334456a765
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.4.11-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.11
id: checkers-0.4.11-3VuWfmvBw1X2gqAyQeTrg7
key: checkers-0.4.11-3VuWfmvBw1X2gqAyQeTrg7
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: 4ff988f9883c6a038939353864934eda
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.4.3/site-local/checkers-0.4.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/checkers-0.4.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/checkers-0.4.11
hs-libraries: HScheckers-0.4.11-3VuWfmvBw1X2gqAyQeTrg7
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr array-0.5.2.0
    base-4.11.1.0 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    semigroupoids-5.3.1-8LPV17szXQVB81Uqgw1FRZ
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             semigroupoids-5.3.1-8LPV17szXQVB81Uqgw1FRZ=fefe65a9667b054c22e0c4972c268b42
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
